@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2004, 2007-2012, 2014-2017 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -73,5 +72,6 @@
 #include <mailutils/sockaddr.h>
 #include <mailutils/cidr.h>
 #include <mailutils/msgset.h>
+#include <mailutils/mimetypes.h>
 
 /* EOF */
